/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <cstring> // @donotremove

#if !defined(__AVX2__) && !(defined(__linux__) && defined(__aarch64__))
namespace folly {

extern "C" void* __folly_memcpy(void* dst, const void* src, std::size_t size) {
  if (size == 0)
    return dst;
  return std::memmove(dst, src, size);
}

} // namespace folly

#endif
